@@ -101,8 +101,6 @@ from synctera_client.apis.paths.persons_person_id import PersonsPersonId
 from synctera_client.apis.paths.persons_person_id_prefill import PersonsPersonIdPrefill
 from synctera_client.apis.paths.rdc_deposits import RdcDeposits
 from synctera_client.apis.paths.rdc_deposits_deposit_id import RdcDepositsDepositId
-from synctera_client.apis.paths.reconciliations import Reconciliations
-from synctera_client.apis.paths.reconciliations_reconciliation_id import ReconciliationsReconciliationId
 from synctera_client.apis.paths.relationships import Relationships
 from synctera_client.apis.paths.relationships_relationship_id import RelationshipsRelationshipId
 from synctera_client.apis.paths.spend_controls import SpendControls
@@ -234,8 +232,6 @@ PathToApi = typing_extensions.TypedDict(
         PathValues.PERSONS_PERSON_ID_PREFILL: PersonsPersonIdPrefill,
         PathValues.RDC_DEPOSITS: RdcDeposits,
         PathValues.RDC_DEPOSITS_DEPOSIT_ID: RdcDepositsDepositId,
-        PathValues.RECONCILIATIONS: Reconciliations,
-        PathValues.RECONCILIATIONS_RECONCILIATION_ID: ReconciliationsReconciliationId,
         PathValues.RELATIONSHIPS: Relationships,
         PathValues.RELATIONSHIPS_RELATIONSHIP_ID: RelationshipsRelationshipId,
         PathValues.SPEND_CONTROLS: SpendControls,
@@ -368,8 +364,6 @@ path_to_api = PathToApi(
         PathValues.PERSONS_PERSON_ID_PREFILL: PersonsPersonIdPrefill,
         PathValues.RDC_DEPOSITS: RdcDeposits,
         PathValues.RDC_DEPOSITS_DEPOSIT_ID: RdcDepositsDepositId,
-        PathValues.RECONCILIATIONS: Reconciliations,
-        PathValues.RECONCILIATIONS_RECONCILIATION_ID: ReconciliationsReconciliationId,
         PathValues.RELATIONSHIPS: Relationships,
         PathValues.RELATIONSHIPS_RELATIONSHIP_ID: RelationshipsRelationshipId,
         PathValues.SPEND_CONTROLS: SpendControls,
