@@ -117,6 +117,7 @@ from synctera_client.model.card_status_request import CardStatusRequest
 from synctera_client.model.card_widget_url_response import CardWidgetUrlResponse
 from synctera_client.model.cash_pickup import CashPickup
 from synctera_client.model.cash_pickup_list import CashPickupList
+from synctera_client.model.cash_pickup_metadata import CashPickupMetadata
 from synctera_client.model.cash_pickup_patch_request import CashPickupPatchRequest
 from synctera_client.model.cash_pickup_post_request import CashPickupPostRequest
 from synctera_client.model.cash_pickup_status import CashPickupStatus
@@ -134,6 +135,7 @@ from synctera_client.model.customer_id1 import CustomerId1
 from synctera_client.model.customer_in_body import CustomerInBody
 from synctera_client.model.customer_kyc_status import CustomerKycStatus
 from synctera_client.model.customer_list import CustomerList
+from synctera_client.model.customer_service_details import CustomerServiceDetails
 from synctera_client.model.customer_type import CustomerType
 from synctera_client.model.customer_verification import CustomerVerification
 from synctera_client.model.customer_verification_result import CustomerVerificationResult
@@ -142,7 +144,10 @@ from synctera_client.model.customer_verify_response import CustomerVerifyRespons
 from synctera_client.model.dc_sign import DcSign
 from synctera_client.model.delete_response import DeleteResponse
 from synctera_client.model.deposit import Deposit
+from synctera_client.model.deposit_get import DepositGet
 from synctera_client.model.deposit_list import DepositList
+from synctera_client.model.deposit_post import DepositPost
+from synctera_client.model.deposit_request import DepositRequest
 from synctera_client.model.detail import Detail
 from synctera_client.model.details import Details
 from synctera_client.model.device_type import DeviceType
@@ -152,7 +157,6 @@ from synctera_client.model.digital_wallet_token_id import DigitalWalletTokenId
 from synctera_client.model.digital_wallet_token_response import DigitalWalletTokenResponse
 from synctera_client.model.digital_wallet_token_state import DigitalWalletTokenState
 from synctera_client.model.digital_wallet_tokenization import DigitalWalletTokenization
-from synctera_client.model.direction import Direction
 from synctera_client.model.disclosure import Disclosure
 from synctera_client.model.disclosure1 import Disclosure1
 from synctera_client.model.disclosure_list import DisclosureList
@@ -188,6 +192,8 @@ from synctera_client.model.external_card_id import ExternalCardId
 from synctera_client.model.external_card_list_response import ExternalCardListResponse
 from synctera_client.model.external_card_request import ExternalCardRequest
 from synctera_client.model.external_card_response import ExternalCardResponse
+from synctera_client.model.external_card_status import ExternalCardStatus
+from synctera_client.model.external_card_update_request import ExternalCardUpdateRequest
 from synctera_client.model.external_card_verifications import ExternalCardVerifications
 from synctera_client.model.fee import Fee
 from synctera_client.model.financial_institution import FinancialInstitution
@@ -243,7 +249,6 @@ from synctera_client.model.outgoing_ach_list import OutgoingAchList
 from synctera_client.model.outgoing_ach_patch import OutgoingAchPatch
 from synctera_client.model.outgoing_ach_request import OutgoingAchRequest
 from synctera_client.model.paginated_response import PaginatedResponse
-from synctera_client.model.paginated_response1 import PaginatedResponse1
 from synctera_client.model.patch_account import PatchAccount
 from synctera_client.model.patch_account_charge_secured import PatchAccountChargeSecured
 from synctera_client.model.patch_account_line_of_credit import PatchAccountLineOfCredit
@@ -322,6 +327,7 @@ from synctera_client.model.relationship import Relationship
 from synctera_client.model.relationship1 import Relationship1
 from synctera_client.model.relationship_in import RelationshipIn
 from synctera_client.model.relationship_list import RelationshipList
+from synctera_client.model.relationship_response import RelationshipResponse
 from synctera_client.model.relationship_role import RelationshipRole
 from synctera_client.model.relationships_list import RelationshipsList
 from synctera_client.model.response_history_item import ResponseHistoryItem
@@ -373,6 +379,7 @@ from synctera_client.model.token_list import TokenList
 from synctera_client.model.token_list_response import TokenListResponse
 from synctera_client.model.transaction import Transaction
 from synctera_client.model.transaction_data import TransactionData
+from synctera_client.model.transaction_dispute import TransactionDispute
 from synctera_client.model.transaction_line import TransactionLine
 from synctera_client.model.transaction_line1 import TransactionLine1
 from synctera_client.model.transaction_list import TransactionList
@@ -380,9 +387,11 @@ from synctera_client.model.transaction_options import TransactionOptions
 from synctera_client.model.transfer_list_response import TransferListResponse
 from synctera_client.model.transfer_request import TransferRequest
 from synctera_client.model.transfer_request_base import TransferRequestBase
+from synctera_client.model.transfer_request_pull import TransferRequestPull
 from synctera_client.model.transfer_request_push import TransferRequestPush
 from synctera_client.model.transfer_response import TransferResponse
 from synctera_client.model.transfer_response_base import TransferResponseBase
+from synctera_client.model.transfer_response_pull import TransferResponsePull
 from synctera_client.model.transfer_response_push import TransferResponsePush
 from synctera_client.model.transfer_reversal_request import TransferReversalRequest
 from synctera_client.model.transfer_type import TransferType
@@ -393,7 +402,6 @@ from synctera_client.model.update_card_image_request import UpdateCardImageReque
 from synctera_client.model.update_gateway_request import UpdateGatewayRequest
 from synctera_client.model.update_transfer import UpdateTransfer
 from synctera_client.model.vendor_info import VendorInfo
-from synctera_client.model.vendor_info1 import VendorInfo1
 from synctera_client.model.vendor_json import VendorJson
 from synctera_client.model.vendor_xml import VendorXml
 from synctera_client.model.verification import Verification
