@@ -106,8 +106,6 @@ class PathValues(str, enum.Enum):
     PERSONS_PERSON_ID_PREFILL = "/persons/{person_id}/prefill"
     RDC_DEPOSITS = "/rdc/deposits"
     RDC_DEPOSITS_DEPOSIT_ID = "/rdc/deposits/{deposit_id}"
-    RECONCILIATIONS = "/reconciliations"
-    RECONCILIATIONS_RECONCILIATION_ID = "/reconciliations/{reconciliation_id}"
     RELATIONSHIPS = "/relationships"
     RELATIONSHIPS_RELATIONSHIP_ID = "/relationships/{relationship_id}"
     SPEND_CONTROLS = "/spend_controls"
